key_value = {
    "Login efectuado com sucesso": "Login efectuado com sucesso",
    "Seleccione a Entidade": "Seleccione a Entidade",
    "Company": "Companhia",
    "Role": "Grupo",
    "Last Login":'Último login',
    "You are successfully logged in.": "Entrou com o login com sucesso.",
    "Welcome": " Bem Vindo",
    'Scaffold Wizard': 'Assistente de Scaffold',
    'Module': 'Módulo',
    'Model': 'Modelo',
    'Select module': 'Selecionar módulo',
    'Model name': 'Nome do modelo',
    'Existing models': 'Modelos existentes',
    'Fields': 'Campos',
    'Name': 'Nome',
    'Type': 'Tipo',
    'Relation app.Model': 'Relação app.Model',
    'Add field': 'Adicionar campo',
    'Preview': 'Pré-visualização',
    'Back': 'Voltar',
    'Next': 'Próximo',
    'Create': 'Criar',
    'CharField': 'Texto curto',
    'TextField': 'Texto longo',
    'IntegerField': 'Número inteiro',
    'DecimalField': 'Decimal',
    'BooleanField': 'Sim / Não',
    'DateField': 'Data',

    'ForeignKey': 'Relação (N-1)',
    'OneToOneField': 'Relação (1-1)',
    'ManyToManyField': 'Lista (N-N)',

    'FileField': 'Arquivo',
    'ImageField': 'Imagem',
    'JSONField': 'JSON / Dados livres',
    'MoneyField': 'Dinheiro'
}
